<?php

namespace Drupal\delete_users_csv;

/**
 * Functions used for batch deletion of users.
 */
class DeleteUsersBatch {

  /**
   * Implementation of callback_batch_operation().
   */
  public static function deleteUsers($users_emails, &$context) {
    $message = t('Deleting users…');
    $results = [];
    if (!empty($users_emails)) {
      $user_storage = \Drupal::entityTypeManager()->getStorage('user');
      foreach ($users_emails as $value) {
        $users = $user_storage->loadByProperties([
          'mail' => $value,
        ]);
        foreach ($users as $user) {
          $results[] = $user->delete();
        }
      }
    }
    $context['message'] = $message;
    $context['results'] = $results;
  }

  /**
   * Implementation of callback_batch_finished().
   */
  public static function deleteUsersCallback($success, $results, $operations) {
    // The 'success' parameter means no fatal PHP errors were detected. All
    // other error management should be handled using 'results'.
    if ($success) {
      $message = \Drupal::translation()->formatPlural(
        count($results),
        'One user deleted.', '@count users deleted.'
      );
    }
    else {
      $message = t('Finished with an error.');
    }
    \Drupal::messenger()->addStatus($message);
    \Drupal::logger('delete_users_csv')->notice($message);
  }

}
