<?php

namespace Drupal\delete_users_csv\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\delete_users_csv\DeleteUsersBatch;
use Drupal\file\Entity\File;

/**
 * Form for deleting users from a CSV upload.
 */
class DeleteUsersCsv extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'delete_users_csv_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $validators = [
      'file_validate_extensions' => ['csv'],
    ];
    $form['users_file'] = [
      '#type' => 'managed_file',
      '#name' => 'my_file',
      '#title' => $this->t('File of email addresses'),
      '#required' => TRUE,
      '#size' => 20,
      '#description' => $this->t('CSV format only. Will delete users for any email address in any row or column of the file.'),
      '#upload_validators' => $validators,
      '#upload_location' => 'public://',
    ];
    $form['actions']['#type'] = 'actions';
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Upload CSV and delete users'),
      '#button_type' => 'primary',
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $users_emails = [];
    $file = $form_state->getValue('users_file');
    $fid = $file[0];
    $file = File::load($fid);
    $destination = $file->toArray()['uri'][0]['value'];
    $file = fopen($destination, 'r');
    while (!feof($file)) {
      $row = fgetcsv($file);
      foreach ($row as $value) {
        if (str_contains($value, '@')) {
          $users_emails[] = trim($value, " \n\r\t\v\x00\xEF\xBB\xBF");
        }
      }
    }
    fclose($file);
    $batch = [
      'title' => $this->t('Deleting Users…'),
      'operations' => [
        [
          [DeleteUsersBatch::class, 'deleteUsers'],
          [$users_emails],
        ],
      ],
      'finished' => [DeleteUsersBatch::class, 'deleteUsersCallback'],
    ];
    batch_set($batch);
  }

}
